==> swc-0.22.0.crate: swc-0.22.0/README.md <==
<p align="center">
  <a href="https://swc.rs/">
    <img alt="babel" src="https://raw.githubusercontent.com/swc-project/logo/master/swc.png" width="546">
  </a>
</p>

<p align="center">
   Make the web (development) faster.
</p>

<p align="center">
   <a href="https://www.npmjs.com/package/@swc/core">
      <img alt="npm Downloads" src="https://img.shields.io/npm/dw/@swc/core">
   </a>
    <a href="https://crates.io/crates/swc_ecma_parser">
      <img alt="undefined" src="https://img.shields.io/crates/d/swc_ecma_parser.svg?label=crates.io%20downloads">
    </a>
</p>
<p align="center">
   <a href="https://github.com/swc-project/swc/actions/workflows/cargo.yml">
      <img alt="CI Status" src="https://github.com/swc-project/swc/actions/workflows/cargo.yml/badge.svg?event=push">
   </a>
   <a href="https://codecov.io/gh/swc-project/swc">
      <img alt="Coverage" src="https://codecov.io/gh/swc-project/swc/branch/master/graph/badge.svg">
   </a>
</p>

swc is a super-fast typescript / javascript compiler written in rust.

# Documentation

Check out the documentation [in the website](https://swc.rs/docs/installation/).

# Features

Please see [comparison with babel](https://swc.rs/docs/comparison-babel).

# Performance

Please see [benchmark results](https://swc.rs/docs/benchmark-transform) on the website.

<h2 align="center">Supporting swc</h2>

<p align="center">
   <a href="#backers">
      <img alt="Backers on Open Collective" src="https://opencollective.com/swc/tiers/backer/badge.svg?label=backer&color=brightgreen" />
   </a>
   <a href="#gold-sponsors">
      <img alt="Gold sponsors on Open Collective" src="https://opencollective.com/swc/tiers/gold-sponsors/badge.svg?label=Gold%20sponsors&color=brightgreen"/>
   </a>
   <a href="#silver-sponsors">
      <img alt="Silver sponsors on Open Collective" src="https://opencollective.com/swc/tiers/silver-sponsors/badge.svg?label=Silver%20sponsors&color=brightgreen"/>
   </a>
   <a href="#bronze-sponsors">
      <img alt="Bronze sponsors on Open Collective" src="https://opencollective.com/swc/tiers/bronze-sponsors/badge.svg?label=Bronze%20sponsors&color=brightgreen"/>
   </a>
</p>

swc is a community-driven project, and is maintained by a group of [volunteers](https://opencollective.com/swc#team). If you'd like to help support the future of the project, please consider:

-   Giving developer time on the project. (Message us on [Github discussions](https://github.com/swc-project/swc/discussions) (preferred) or [Slack](https://swc-org.slack.com/) for guidance!)
-   [Slackin for swc](https://swc-slackin.herokuapp.com)
-   Giving funds by becoming a sponsor (see below)!

## Open Collective Sponsors

Become a sponsor and get your logo on our README on Github with a link to your site. [[Become a sponsor](https://opencollective.com/swc#sponsor)]

<h2 id="gold-sponsers" align="center">Gold Sponsors</h2>
<a href="https://opencollective.com/swc">
    <img src="https://opencollective.com/swc/tiers/gold-sponsors.svg?avatarHeight=64">
</a>

<h2 id="silver-sponsers" align="center">Silver Sponsors</h2>
<a href="https://opencollective.com/swc">
    <img src="https://opencollective.com/swc/tiers/silver-sponsors.svg?avatarHeight=64">
</a>

<h2 id="bronze-sponsers" align="center">Bronze Sponsors</h2>
<a href="https://opencollective.com/swc">
    <img src="https://opencollective.com/swc/tiers/bronze-sponsors.svg?avatarHeight=64">
</a>

<h2 id="backers" align="center">Backers</h2>
<a href="https://opencollective.com/swc">
    <img src="https://opencollective.com/swc/tiers/backer.svg?avatarHeight=64">
</a>

[Become a backer](https://opencollective.com/swc#backer) and get your image on our README on Github with a link to your site.

## Contributing

See [CONTRIBUTING.md](CONTRIBUTING.md). You may also find the architecture
documentation useful ([ARCHITECTURE.md](ARCHITECTURE.md)).

## License

swc is primarily distributed under the terms of both the MIT license
and the Apache License (Version 2.0).

See LICENSE-APACHE and LICENSE-MIT for details.

[babel]: https://github.com/babel/babel
[closure compiler]: https://github.com/google/closure-compiler
[rust]: https://www.rust-lang.org

==> swc-0.39.0.crate: swc-0.39.0/README.md <==
<p align="center">
  <a href="https://swc.rs/">
    <img alt="babel" src="https://raw.githubusercontent.com/swc-project/logo/master/swc.png" width="546">
  </a>
</p>

<p align="center">
   Make the web (development) faster.
</p>

<p align="center">
   <a href="https://www.npmjs.com/package/@swc/core">
      <img alt="npm Downloads" src="https://img.shields.io/npm/dw/@swc/core">
   </a>
    <a href="https://crates.io/crates/swc_ecma_parser">
      <img alt="undefined" src="https://img.shields.io/crates/d/swc_ecma_parser.svg?label=crates.io%20downloads">
    </a>
</p>
<p align="center">
   <a href="https://github.com/swc-project/swc/actions/workflows/cargo.yml">
      <img alt="CI Status" src="https://github.com/swc-project/swc/actions/workflows/cargo.yml/badge.svg?event=push">
   </a>
</p>

swc is a super-fast typescript / javascript compiler written in rust. It's a library for rust and javascript at the same time. If you are using swc from rust, see [rustdoc](https://rustdoc.swc.rs/swc/) and for most users, your entrypoint for using library will be [parser](https://rustdoc.swc.rs/swc_ecma_parser/).

If you are using swc from javascript, please refer to [docs on the website](https://swc.rs/docs/installation/).

# Documentation

Check out the documentation [in the website](https://swc.rs/docs/installation/).

# Features

Please see [comparison with babel](https://swc.rs/docs/comparison-babel).

# Performance

Please see [benchmark results](https://swc.rs/docs/benchmark-transform) on the website.

<h2 align="center">Supporting swc</h2>

<p align="center">
   <a href="#backers">
      <img alt="Backers on Open Collective" src="https://opencollective.com/swc/tiers/backer/badge.svg?label=backer&color=brightgreen" />
   </a>
   <a href="#gold-sponsors">
      <img alt="Gold sponsors on Open Collective" src="https://opencollective.com/swc/tiers/gold-sponsors/badge.svg?label=Gold%20sponsors&color=brightgreen"/>
   </a>
   <a href="#silver-sponsors">
      <img alt="Silver sponsors on Open Collective" src="https://opencollective.com/swc/tiers/silver-sponsors/badge.svg?label=Silver%20sponsors&color=brightgreen"/>
   </a>
   <a href="#bronze-sponsors">
      <img alt="Bronze sponsors on Open Collective" src="https://opencollective.com/swc/tiers/bronze-sponsors/badge.svg?label=Bronze%20sponsors&color=brightgreen"/>
   </a>
</p>

swc is a community-driven project, and is maintained by a group of [volunteers](https://opencollective.com/swc#team). If you'd like to help support the future of the project, please consider:

-   Giving developer time on the project. (Message us on [Github discussions](https://github.com/swc-project/swc/discussions) (preferred) or [Slack](https://swc-org.slack.com/) for guidance!)
-   Giving funds by becoming a sponsor (see https://opencollective.com/swc)!

## Contributing

See [CONTRIBUTING.md](CONTRIBUTING.md). You may also find the architecture
documentation useful ([ARCHITECTURE.md](ARCHITECTURE.md)).

## License

swc is primarily distributed under the terms of both the MIT license
and the Apache License (Version 2.0).

See LICENSE-APACHE and LICENSE-MIT for details.

[babel]: https://github.com/babel/babel
[closure compiler]: https://github.com/google/closure-compiler
[rust]: https://www.rust-lang.org
